@@ -1,9 +1,10 @@
 from abc import abstractmethod
+from typing import Optional
 
 import torch
 from torch import Tensor, nn
 
-from easyfsl.utils import compute_backbone_output_shape, compute_prototypes
+from easyfsl.methods.utils import compute_prototypes
 
 
 class FewShotClassifier(nn.Module):
@@ -11,20 +12,18 @@ class FewShotClassifier(nn.Module):
     Abstract class providing methods usable by all few-shot classification algorithms
     """
 
-    def __init__(self, backbone: nn.Module, use_softmax: bool = False):
+    def __init__(self, backbone: Optional[nn.Module] = None, use_softmax: bool = False):
         """
         Initialize the Few-Shot Classifier
         Args:
             backbone: the feature extractor used by the method. Must output a tensor of the
-                appropriate shape (depending on the method)
+                appropriate shape (depending on the method).
+                If None is passed, the backbone will be initialized as nn.Identity().
             use_softmax: whether to return predictions as soft probabilities
         """
         super().__init__()
 
-        self.backbone = backbone
-        self.backbone_output_shape = compute_backbone_output_shape(backbone)
-        self.feature_dimension = self.backbone_output_shape[0]
-
+        self.backbone = backbone if backbone is not None else nn.Identity()
         self.use_softmax = use_softmax
 
         self.prototypes = torch.tensor(())
@@ -38,11 +37,10 @@ class FewShotClassifier(nn.Module):
     ) -> Tensor:
         """
         Predict classification labels.
-
         Args:
-            query_images: images of the query set
+            query_images: images of the query set of shape (n_query, **image_shape)
         Returns:
-            a prediction of classification scores for query images
+            a prediction of classification scores for query images of shape (n_query, n_classes)
         """
         raise NotImplementedError(
             "All few-shot algorithms must implement a forward method."
@@ -55,12 +53,10 @@ class FewShotClassifier(nn.Module):
         support_labels: Tensor,
     ):
         """
-        Harness information from the support set, so that query labels can later be predicted using
-        a forward call
-
+        Harness information from the support set, so that query labels can later be predicted using a forward call.
         Args:
-            support_images: images of the support set
-            support_labels: labels of support set images
+            support_images: images of the support set of shape (n_support, **image_shape)
+            support_labels: labels of support set images of shape (n_support, )
         """
         raise NotImplementedError(
             "All few-shot algorithms must implement a process_support_set method."
@@ -77,10 +73,9 @@ class FewShotClassifier(nn.Module):
         If the option is chosen when the classifier is initialized, we perform a softmax on the
         output in order to return soft probabilities.
         Args:
-            output: output of the forward method
-
+            output: output of the forward method of shape (n_query, n_classes)
         Returns:
-            output as it was, or output as soft probabilities
+            output as it was, or output as soft probabilities, of shape (n_query, n_classes)
         """
         return output.softmax(-1) if self.use_softmax else output
 
@@ -88,10 +83,9 @@ class FewShotClassifier(nn.Module):
         """
         Compute prediction logits from their euclidean distance to support set prototypes.
         Args:
-            samples: features of the items to classify
-
+            samples: features of the items to classify of shape (n_samples, feature_dimension)
         Returns:
-            prediction logits
+            prediction logits of shape (n_samples, n_classes)
         """
         return -torch.cdist(samples, self.prototypes)
 
@@ -99,28 +93,35 @@ class FewShotClassifier(nn.Module):
         """
         Compute prediction logits from their cosine distance to support set prototypes.
         Args:
-            samples: features of the items to classify
-
+            samples: features of the items to classify of shape (n_samples, feature_dimension)
         Returns:
-            prediction logits
+            prediction logits of shape (n_samples, n_classes)
         """
         return (
             nn.functional.normalize(samples, dim=1)
             @ nn.functional.normalize(self.prototypes, dim=1).T
         )
 
-    def store_support_set_data(
+    def compute_prototypes_and_store_support_set(
         self,
         support_images: Tensor,
         support_labels: Tensor,
     ):
         """
-        Extract support features, compute prototypes,
-            and store support labels, features, and prototypes
+        Extract support features, compute prototypes, and store support labels, features, and prototypes.
         Args:
-            support_images: images of the support set
-            support_labels: labels of support set images
+            support_images: images of the support set of shape (n_support, **image_shape)
+            support_labels: labels of support set images of shape (n_support, )
         """
         self.support_labels = support_labels
         self.support_features = self.backbone(support_images)
+        self._raise_error_if_features_are_multi_dimensional(self.support_features)
         self.prototypes = compute_prototypes(self.support_features, support_labels)
+
+    @staticmethod
+    def _raise_error_if_features_are_multi_dimensional(features: Tensor):
+        if len(features.shape) != 2:
+            raise ValueError(
+                "Illegal backbone or feature shape. "
+                "Expected output for an image is a 1-dim tensor."
+            )
