@@ -1,7 +1,7 @@
 import torch
 from torch import Tensor, nn
 
-from easyfsl.methods import FewShotClassifier
+from .few_shot_classifier import FewShotClassifier
 
 
 class Finetune(FewShotClassifier):
@@ -46,11 +46,8 @@ class Finetune(FewShotClassifier):
     ):
         """
         Overrides process_support_set of FewShotClassifier.
-        Args:
-            support_images: images of the support set
-            support_labels: labels of support set images
         """
-        self.store_support_set_data(support_images, support_labels)
+        self.compute_prototypes_and_store_support_set(support_images, support_labels)
 
     def forward(
         self,
@@ -60,10 +57,6 @@ class Finetune(FewShotClassifier):
         Overrides forward method of FewShotClassifier.
         Fine-tune prototypes based on support classification error.
         Then classify w.r.t. to cosine distance to prototypes.
-        Args:
-            query_images: images of the query set
-        Returns:
-            a prediction of classification scores for query images
         """
         query_features = self.backbone.forward(query_images)
 
